@@ -19,13 +19,14 @@ def issue(issue_id):
     """
     Close a specific ISSUE_ID.
 
-    ISSUE_ID is the ID number of a work item.
+    ISSUE_ID is the ID number of a work item. '#' prefix is allowed.
     You can specify multiple IDs by separating with a space.
     """
     organization = get_config("organization")
     state = "Closed"
 
     for id in issue_id:
+        id = str(id).lstrip("#")
         cmd = f"az boards work-item update --id {id} --state '{state}' "
         cmd += f"--org '{organization}'"
         result = run_command(cmd)
@@ -39,13 +40,14 @@ def pr(pr_id):
     """
     Close a specific PR_ID.
 
-    PR_ID is the ID number of a pull request.
+    PR_ID is the ID number of a pull request. '!' prefix is allowed.
     You can specify multiple IDs by separating with a space.
     """
     organization = get_config("organization")
     state = "abandoned"
 
     for id in pr_id:
+        id = str(id).lstrip("!")
         cmd = f"az repos pr update --id {id} --status '{state}' "
         cmd += f"--org '{organization}'"
         result = run_command(cmd)
